package com.yizhi.application.controller.remote;

import com.alibaba.fastjson.JSONObject;
import com.yizhi.application.orm.id.IdGenerator;
import com.yizhi.application.service.EnrollService;
import com.yizhi.core.application.enums.InternationalEnums;
import com.yizhi.enroll.application.vo.ProjectAccountVO;
import com.yizhi.enroll.application.vo.ReturnEnrollVO;
import com.yizhi.enroll.application.vo.domain.Enroll;
import com.yizhi.util.application.domain.BizResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
 * 报名主体表，入口在培训项目 前端控制器 管理端
 * </p>
 *
 * @author bob123
 * @since 2018-03-07
 */
@RestController
@RequestMapping(path = "/remote/")
public class EnrollManageController {

    private static final Logger LOGGER = LoggerFactory.getLogger(EnrollManageController.class);

    @Autowired
    private EnrollService enrollService;

    @Autowired
    IdGenerator idGenerator;

    @PostMapping("/manage/enroll/insertEnroll")
    public Long insertEnroll(@RequestBody Enroll enroll) {
        com.yizhi.application.domain.Enroll enrollDomain = new com.yizhi.application.domain.Enroll();
        BeanUtils.copyProperties(enroll,enrollDomain);
        return enrollService.insertEnroll(enrollDomain);
    }

    /**
     * 新增项目 版本2
     * 相对insertEnroll()方法；新增参数校验；2.修改返回值
     */
    @PostMapping("/manage/enroll/insertEnroll/v2")
    public BizResponse<String> insertEnrollV2(@RequestBody Enroll enroll) {
        com.yizhi.application.domain.Enroll enrollDomain = new com.yizhi.application.domain.Enroll();
        enrollDomain.setNeedAudit(enroll.getNeedAudit());
        Integer enablePay = enroll.getEnablePay();
        enrollDomain.setEnablePay(enablePay);
        if (null != enablePay && enablePay.equals(1)){
            //开启报名付费,不需要审核
            enrollDomain.setNeedAudit(0);
            enrollDomain.setActualPrice(enroll.getActualPrice());
            enrollDomain.setOriginalPrice(enroll.getOriginalPrice());
        }
        enrollDomain.setStartTime(enroll.getStartTime());
        enrollDomain.setEndTime(enroll.getEndTime());
        enrollDomain.setNotice(enroll.getNotice());
        enrollDomain.setPersonLimitNum(enroll.getPersonLimitNum());
        enrollDomain.setTrainingProjectId(enroll.getTrainingProjectId());
        Long aLong = enrollService.insertEnroll(enrollDomain);
        if (null == aLong || aLong.compareTo(0L) < 0){
            LOGGER.error("报名新增失败;入参 = {}", JSONObject.toJSONString(enroll));
            return BizResponse.fail(InternationalEnums.INTERNATIONALIZATIONWORDCONTROLLER4.getCode());
        }
        return BizResponse.ok();
    }

    @PostMapping("/manage/enroll/updateEnroll")
    public Long updateEnroll(@RequestBody Enroll enroll) {
        com.yizhi.application.domain.Enroll enrollDomain = new com.yizhi.application.domain.Enroll();
        BeanUtils.copyProperties(enroll,enrollDomain);
        return enrollService.updateEnroll(enrollDomain);
    }

    @GetMapping("/manage/enroll/view/{id}")
    public com.yizhi.enroll.application.vo.domain.Enroll selectByProjectId(@PathVariable("id") Long id) {
       /* MessageReceiverVO messageReceiverVO;
        MessageVO messageVO;
        List<Integer> sendTypes = new ArrayList<Integer>();
        LOGGER.info("调用消息提醒");
        List<MessageReceiverVO> messageReceiverVOS = null;
        List<MessageVO> messageVOS = new ArrayList<MessageVO>();
        messageVO = new MessageVO();
        messageVO.setSubject("test message 7/7"); // 消息标题
        messageVO.setMessageType(Integer.parseInt(MessageType.KS.getKey())); // 消息类型(0自定义消息1学习计划2考试3调研4投票5报名6作业7签到8项目)
        messageVO.setTaskId(800000L); // 关联业务id,自定义消息为0
        messageVO.setContext("mcz"); // 消息内容
        messageVO.setHappenTime(new Date());
        messageVO.setAheadType(AheadType.ODAY.getCode()); // 提前时间类型
        messageVO.setVisibleRange(2);

        // 更加可见范围来设置
        messageReceiverVOS = new ArrayList<MessageReceiverVO>();
        for (int i = 0; i < 10; i++) {
            messageReceiverVO = new MessageReceiverVO();
            messageReceiverVO.setType(2);
            messageReceiverVO.setReceiverId(idGenerator.generate());
            messageReceiverVOS.add(messageReceiverVO);
        }

        messageVO.setReceiverVOs(messageReceiverVOS); // 关联人列表
        sendTypes.add(Integer.parseInt(SendType.MAIL.getCode()));// 邮件mcz
        sendTypes.add(Integer.parseInt(SendType.INSITE.getCode()));// 站内消息 mcz
        messageVO.setSendTypes(sendTypes);
        messageVOS.add(messageVO);

        try {
            // systemMessageClient.add(messageVOS);
            // List<MessageVO> list = systemMessageClient.list(800000L);
            messageVO.setId(1004631225070448640L);
            // systemMessageClient.update(messageVOS);
            systemMessageClient.delete(messageVOS);
            LOGGER.info("调用消息提醒成功ok");
        } catch (Exception e) {
            LOGGER.error("调用消息提醒失败");
            e.printStackTrace();
        }*/
        com.yizhi.application.domain.Enroll enroll = enrollService.selectByProjectId(id);
        if (null == enroll){
            return null;
        }
        com.yizhi.enroll.application.vo.domain.Enroll enrollVo = new Enroll();
        BeanUtils.copyProperties(enroll,enrollVo);
        return enrollVo;
    }

    @PostMapping("/manage/enroll/selectEnrollByProjectId")
    public ReturnEnrollVO selectEnrollByProjectId(@RequestBody ProjectAccountVO vo) {
        return enrollService.selectEnrollByProjectId(vo);
    }

    @PostMapping("/manage/enroll/delete")
    public Integer deleteEnrollByProjectId(@RequestBody ProjectAccountVO vo){
        return enrollService.deleteEnrollByProjectId(vo);
    }
}
