package com.yizhi.application.util;


import com.yizhi.core.application.context.RequestContext;
import com.yizhi.core.application.publish.CloudEventPublisher;
import com.yizhi.enroll.application.enums.EvenType;
import com.yizhi.enroll.application.vo.MessageRemindVo;
import com.yizhi.enroll.application.vo.TaskVo;
import com.yizhi.message.application.enums.RelationType;
import com.yizhi.training.application.vo.domain.TrainingProjectVo;
import org.apache.commons.lang3.time.DateUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;

@Component
public class EnrollEvenSendMessage {


    @Autowired
    private CloudEventPublisher cloudEventPublisher;

    private Logger logger = LoggerFactory.getLogger(EnrollEvenSendMessage.class);


    /**
     * 触发事件,根据可见范围发消息
     *
     * @param trainingProject 业务参数对象
     * @param accountId
     */
    public void evenSendMessage(TrainingProjectVo trainingProject, Long enrollId, Date enrollEndTime, Long accountId, EvenType evenType) {
        if (enrollEndTime == null) {
            logger.info("缺失必需参数！！");
        }

        TaskVo taskVo = new TaskVo();
        if (trainingProject != null) {
            taskVo.setTaskName(trainingProject.getName());
            taskVo.setTaskEndTime(trainingProject.getEndTime());
            taskVo.setTaskStratTime(trainingProject.getStartTime());
        }
        MessageRemindVo vo = new MessageRemindVo();
        vo.setTaskVo(taskVo);
        vo.setVisibleRange(trainingProject.getVisibleRange());
        vo.setMessageId(evenType.getKey());
        vo.setMessageType(3);
        vo.setRelationId(enrollId);
        vo.setRelationType(RelationType.BM.getKey());
        vo.setSendType(1);
        //定时任务默认五分钟执行一次   这里默认暂时不延迟时间
        vo.setSendTime(DateUtils.addMinutes(new Date(), 0));
        if (accountId != null) {
            vo.setAccountId(accountId);
        }
        RequestContext requestContext = new RequestContext();
        requestContext.setCompanyId(trainingProject.getCompanyId());
        requestContext.setSiteId(trainingProject.getSiteId());
        requestContext.setAccountId(trainingProject.getCreateById());
        requestContext.setAccountName(trainingProject.getCreateByName());
        vo.setRequestContext(requestContext);
        try {
            //临时取消触发功能
//            cloudEventPublisher.publish(Constans.MESSAGE_QUEUE, new EventWrapper<MessageRemindVo>(null, vo));
//            logger.error("发送消息成功===========");
        } catch (Exception e) {
            e.printStackTrace();
            logger.error("发送消息失败=====================", e);
        }

    }

//    /**
//     * 系统模板,发消息
//     *
//     * @param trainingProject 业务参数对象
//     */
//    public void systemSendMessage(TrainingProject trainingProject, Date enrollEndTime, MessageRemindVo remindVo, RequestContext context) {
//        MessageRemindVo vo = new MessageRemindVo();
//        if (remindVo.getMessageType() == null || remindVo.getIsChangge() == null || remindVo.getSendType() == null) {
//            logger.info("相关参数缺失！！");
//        }
//
//
//        if (remindVo.getHasDeleted()) {
//            vo.setHasDeleted(remindVo.getHasDeleted());
//            cloudEventPublisher.publish(Constans.MESSAGE_QUEUE, new EventWrapper<MessageRemindVo>(null, vo));
//        } else {
//
//            if (trainingProject != null) {
//                if (!CollectionUtils.isEmpty(remindVo.getMessageTaskRemindVos())) {
//
//                    TaskVo taskVo = new TaskVo();
//                    taskVo.setTaskName(trainingProject.getName());
//                    taskVo.setTaskStratTime(trainingProject.getStartTime());
//                    taskVo.setTaskEndTime(trainingProject.getEndTime());
//
//                    vo.setRelationId(trainingProject.getId());
//                    vo.setRelationType(RelationType.BM.getKey());
//                    vo.setMessageType(remindVo.getMessageType());
//                    vo.setMessageId(remindVo.getMessageId());
//                    vo.setIsChangge(vo.getIsChangge());
//                    vo.setMessageTaskRemindVos(remindVo.getMessageTaskRemindVos());
//                    vo.setSendType(remindVo.getSendType());
//                    vo.setVisibleRange(trainingProject.getVisibleRange());
//                    if (context == null) {
//                        context = new RequestContext();
//                        context.setCompanyId(trainingProject.getCompanyId());
//                        context.setSiteId(trainingProject.getSiteId());
//                        context.setAccountName(trainingProject.getCreateByName());
//                        context.setAccountId(trainingProject.getCreateById());
//                    }
//                    vo.setRequestContext(context);
//                    vo.setTaskVo(taskVo);
//                    try {
//                        cloudEventPublisher.publish(Constans.MESSAGE_QUEUE, new EventWrapper<MessageRemindVo>(null, vo));
//                        logger.error("发送消息成功=====================");
//                    } catch (Exception e) {
//                        e.printStackTrace();
//                        logger.error("发送消息失败=====================", e);
//                    }
//                }
//            }
//        }
//    }
}

